.. _experimental_api:

Experimental API
================

This page describes the new ESMValCore API.
The API module is available in the submodule ``esmvalcore.experimental``.
The API is under development, so use at your own risk!

.. toctree::

   esmvalcore.api.config
   esmvalcore.api.recipe
   esmvalcore.api.recipe_output
   esmvalcore.api.recipe_metadata
   esmvalcore.api.utils
